/* $Id: robotester.c,v 1.7 2007/07/03 20:40:43 gumpu Exp $ */

/*x**ih* DOCUWALA/ROBOTester
 * FUNCTION
 *   A unittest framework.  ROBOTester consists of two parts.
 *   * a library that you use to create a program called tester.  
 *     This tester creates and executes testcases.
 *   * a perl script, roborun.pl, that uses this tester to run a series
 *     of testcases and collects and analyses the output.
 *****
 */

/****h* ROBOTester/librobotester
 * FUNCTION
 *   librobotester is a library that you use to create a 
 *   program called tester. This tester creates and 
 *   executes testcases.
 *
 *   The library can be divided in three main parts:
 *   * a part to create testcases
 *   * a part to register testcases and testsuites.
 *   * The part responsible for running and list testcases.
 *
 *   You create testcases with a number of assertion functions.  A
 *   testcase will consist of a number of assertions.  Each assertion
 *   must be true for a testcase to succeed.
 *   Currently the following assertions are supported:
 *   * r_ok() -- assert an expression is non-zero.
 *   * r_notok() -- assert an expression is zero.
 *
 *   Once you have created testcases you can register and collect
 *   them in a testsuite.
 *   The following functions are available for this:
 *   * RBT_CreateSuite()
 *   * RBT_AddCase()
 *   * RBT_AddFullCase()
 *
 *   Once you have a number of testsuites, you run them
 *   with:
 *   * RBT_Testit()
 *
 ****
 */


#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include "testsuite.h"


void usage( void )
{
    printf("Usage:\n"
           "  robotester list\n"
           "  robotester run <testsuite name> <testcase name>\n");
}



/****h* librobotester/RBT_Testit
 * FUNCTION
 *   Provide a commandline interface to list en
 *   run the testcases.
 * SOURCE
 */

int RBT_Testit( int argc, char** argv )
{

    if ( argc == 2 )
    {
        if ( strcmp( argv[ 1 ], "list" ) == 0 )
        {
            RBT_ListCases();
        }
        else
        {
            usage();
        }
    }
    else if ( argc == 4 )
    {
        if ( strcmp( argv[ 1 ], "run" ) == 0 )
        {
            RBT_RunById( argv[2], argv[3] );
        }
        else
        {
            usage();
        }
    }
    else
    {
        usage();
    }

    return EXIT_SUCCESS;
}

/*********/

