#ifndef TESTCASE_H
#define TESTCASE_H

/* $Id: testcase.h,v 1.6 2007/07/01 23:32:39 gumpu Exp $ */


/****t* Testcase/TestFunction
 * FUNCTION
 *   The type of the testfunction.  All testfunctions and teardown and
 *   setup functions should be functions that take no parameters and
 *   return nothing.
 *
 *   This is a function pointer. See http://www.function-pointer.org/ for
 *   a nice tutorial on function pointers.
 * SOURCE
 */

typedef void (*TestFunction)(void);

/*****/

/****t* Testcase/SetupFunction
 * FUNCTION
 *   The type of the setup function. See TestFunction.
 * SOURCE
 */

typedef void (*SetupFunction)(void);

/*****/

/****t* Testcase/TearDownFunction
 * FUNCTION
 *   The type of the teardown function. See TestFunction.
 * SOURCE
 */

typedef void (*TearDownFunction)(void);

/*****/

/****s* Testcase/RBT_TestCase
 * FUNCTION
 *   Information about a testcase. Testcases are
 *   stored in a testsuite ( RBT_TestSuite ).
 *   A testcase consists of upto three functions:
 *   * a setup function, that sets up the environment (variables,
 *     files, etc) necessary to carry out a test.
 *   * a test function, this is the function that carries out the 
 *     actual test.
 *   * a teardown function, this releases any resources claimed in
 *     your setup function and/or testfunction.
 * ATTRIBUTES
 *   * next  -- pointer to the next testcase,
 *              this is used to store the testcases as
 *              a linked list in a RBT_TestSuite.
 *   * id    -- a unique ID for this testcase.
 *   * test_function
 *   * setup_function
 *   * teardown_function
 * SOURCE
 */

typedef struct RBT_TestCase
{
    struct RBT_TestCase* next;
    char* id;
    TestFunction  test_function;
    SetupFunction setup_function;
    TestFunction  teardown_function;
} RBT_TestCase;

/*****/

RBT_TestCase* RBT_CreateTestCase( char* id, 
    SetupFunction setup_function,
    TestFunction  test_function,
    TestFunction  teardown_function
        );

void RBT_Run( RBT_TestCase* testcase );

#endif /* TESTCASE_H */

