#ifndef TESTSUITE_H
#define TESTSUITE_H

/* $Id: testsuite.h,v 1.5 2004/01/04 19:13:36 gumpu Exp $ */

#include "testcase.h"

/****s* TestSuite/RBT_TestSuite
 * FUNCTION
 *   A testsuite is a collection of testcases.  Usually you have one
 *   of more testsuites to test your application.
 * ATTRIBUTES
 *   o first_testcase  -- the first testcase in a linked list of
 *                        testcases.
 *   o last_testcase   -- the last testcase in a linked list of
 *                        testcases.  Having this makes it easier to
 *                        store the testcases in the same order they
 *                        are added.
 * SOURCE
 */

typedef struct RBT_TestSuite
{
    struct RBT_TestSuite* next;
    char*  id;
    RBT_TestCase* first_testcase;
    RBT_TestCase* last_testcase;
} RBT_TestSuite;

/****/

RBT_TestSuite* RBT_CreateSuite( char* id );
RBT_TestSuite* RBT_GetFirstTestSuite( void );
RBT_TestSuite* RBT_GetNextTestSuite( RBT_TestSuite* suite );

void RBT_AddCase_Func( RBT_TestSuite* suite, char* id,
    SetupFunction setup_function,
    TestFunction  test_function,
    TestFunction  teardown_function
);

/****f* TestSuite/RBT_AddCase
 * FUNCTION
 *   Create a new testcase and add it to a testsuite.  In this case
 *   the testcase only has a testfunction and no setup and teardown
 *   function.
 *
 *   This is a macro that points to RBT_AddCase_Func().
 * INPUTS
 *   o suite  -- the testsuite the testcase is to be added to.
 *   o test_function -- the testfunction to create the testcase with.
 * SOURCE
 */

#define RBT_AddCase( suite, test_function ) \
   RBT_AddCase_Func( suite, #test_function, 0, test_function, 0 )

/*****/

/****f* TestSuite/RBT_AddFullCase
 * FUNCTION
 *   Create a new testcase and add it to a testsuite.  In this case
 *   the testcase is a full testcase with a teardown and setup
 *   function.   To add a testcase without a teardown and setup
 *   function use RBT_AddCase().
 *
 *   This is a macro that points to RBT_AddCase_Func().
 * INPUTS
 *   o suite  -- the testsuite the testcase is to be added to.
 *   o setup_function     -- the setup function to create the testcase with.
 *   o test_function      -- the testfunction
 *   o teardown_function  -- the teardown function
 * SOURCE
 */

#define RBT_AddFullCase( suite, setup_function, test_function, teardown_function ) \
   RBT_AddCase_Func( suite, #test_function, setup_function, test_function, teardown_function )

/******/

void RBT_ListCases( void );
void RBT_RunById( char* suite_id, char* case_id );

#endif /* TESTSUITE_H */
